@@ -4,16 +4,17 @@
 ;; Copyright (C) 2019-2021  Campbell Barton
 
 ;; Author: Campbell Barton <ideasman42@gmail.com>
+
 ;; URL: https://codeberg.org/ideasman42/emacs-hl-block-mode
-;; Keywords: convenience, faces
-;; Version: 0.2
+;; Package-Version: 20250913.2251
+;; Package-Revision: fdb50b4d2048
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
 
 ;; Highlight blocks surrounding the cursor.
 
-;;; Usage:
+;;; Usage
 
 ;; (hl-block-mode)        ; Activate in the current buffer.
 ;; (hl-block-global-mode) ; Activate globally for all buffers.
@@ -21,7 +22,7 @@
 ;;; Code:
 
 (eval-when-compile
-  ;; For pcase macros.
+  ;; For `pcase-dolist'.
   (require 'pcase))
 
 
@@ -49,67 +50,67 @@
   "Highlight nested blocks or brackets."
   :group 'convenience)
 
-(defcustom hl-block-bracket (list ?{)
-  "Characters to use as starting brackets (set to nil to use all brackets)."
-  :type '(choice (const nil) (repeat character)))
+(defcustom hl-block-bracket "{"
+  "Characters to use as a starting bracket (set to nil to use all brackets)."
+  :type '(choice (const nil) string))
 
 (defcustom hl-block-delay 0.2
   "Idle time to wait before highlighting (in seconds)."
-  :type 'number)
+  :type 'float)
 
 (defcustom hl-block-multi-line nil
-  "When non-nil, skip highlighting nested blocks on the same line.
+  "Skip highlighting nested blocks on the same line.
 
 Useful for languages that use S-expressions to avoid overly nested highlighting."
   :type 'boolean)
 
 (defcustom hl-block-single-level nil
-  "When non-nil, highlight only a single level instead of all levels."
+  "Only highlight a single level, otherwise highlight all levels."
   :type 'boolean)
 
 (defcustom hl-block-style 'color-tint
-  "Style used for highlighting blocks."
+  "Only highlight a single level."
   :type
-  '(choice (const :tag "Tint the background at each level." color-tint)
-           (const :tag "Highlight surrounding brackets." bracket)))
+  '(choice (symbol :tag "Tint the background at each level `hl-block-color-tint'." color-tint)
+           (symbol :tag "Highlight surrounding brackets using `hl-block-bracket-face'." bracket)))
 
-;; Used with the `color-tint' draw style.
+;; For `color-tint' draw style.
 (defcustom hl-block-color-tint "#040404"
   "Color to add/subtract from the background each scope step."
   :type 'color)
 
-;; Used with the `bracket' draw style.
+;; For `bracket' draw style.
 (defcustom hl-block-bracket-face '(:inverse-video t)
   "Face used when `hl-block-style' is set to `bracket'."
-  :type '(choice face plist))
+  :type 'face)
 
 (defcustom hl-block-mode-lighter ""
-  "Lighter for `hl-block-mode'."
+  "Lighter for option `hl-block-mode'."
   :type 'string)
 
 
 ;; ---------------------------------------------------------------------------
 ;; Internal Variables
 
-(defvar-local hl-block--overlays nil
-  "List of overlays used for highlighting.")
+(defvar-local hl-block--overlay nil)
 
 
 ;; ---------------------------------------------------------------------------
 ;; Internal Bracket Functions
 
 (defun hl-block--syntax-prev-bracket (pt)
-  "Find the previous bracket position matching `hl-block-bracket'.
-PT is typically the result of calling `point'."
+  "A version of `syntax-ppss' to match curly braces.
+PT is typically the `(point)'."
   (declare (important-return-value t))
-  (when-let* ((beg
-               (ignore-errors
-                 (nth 1 (syntax-ppss pt)))))
-    (cond
-     ((memq (char-after beg) hl-block-bracket)
-      beg)
-     (t
-      (hl-block--syntax-prev-bracket (1- beg))))))
+  (let ((beg
+         (ignore-errors
+           (nth 1 (syntax-ppss pt)))))
+    (when beg
+      (cond
+       ((memq (char-after beg) hl-block-bracket)
+        beg)
+       (t
+        (hl-block--syntax-prev-bracket (1- beg)))))))
 
 
 (defun hl-block--find-range (pt)
@@ -123,7 +124,7 @@ PT is typically the result of calling `point'."
            (ignore-errors
              (nth 1 (syntax-ppss pt)))))))
     (when beg
-      ;; Note that `end' may be nil for unmatched brackets.
+      ;; Note that `end' may be nil for un-matched brackets.
       ;; The caller must handle this case.
       (let ((end
              (ignore-errors
@@ -132,18 +133,20 @@ PT is typically the result of calling `point'."
 
 
 (defun hl-block--find-all-ranges (pt)
-  "Return ranges starting from PT, innermost to outermost."
+  "Return ranges starting from PT, outer-most to inner-most."
   (declare (important-return-value t))
-  (when-let* ((range (hl-block--find-range pt)))
-    ;; When no further range is found, recursion terminates.
-    (cons range (hl-block--find-all-ranges (car range)))))
+  (let ((range (hl-block--find-range pt)))
+    (when range
+      ;; When the previous range is nil, this simply terminates the list.
+      (cons range (hl-block--find-all-ranges (car range))))))
 
 
 (defun hl-block--find-single-range (pt)
-  "Return a list with the innermost range around PT."
+  "Return ranges starting from PT, only a single level."
   (declare (important-return-value t))
-  (when-let* ((range (hl-block--find-range pt)))
-    (list range)))
+  (let ((range (hl-block--find-range pt)))
+    (when range
+      (list range))))
 
 
 (defun hl-block--syntax-skip-to-multi-line ()
@@ -169,14 +172,14 @@ The point will only ever be moved backward."
 ;; Internal Color Tint (Draw Style)
 
 (defun hl-block--color-values-as-string (color)
-  "Convert COLOR vector to a hex color string.
-COLOR is a 3-element vector of RGB values."
+  "Build a color from COLOR.
+Inverse of `color-values'."
   (declare (important-return-value t))
   (format "#%02x%02x%02x" (ash (aref color 0) -8) (ash (aref color 1) -8) (ash (aref color 2) -8)))
 
 
 (defun hl-block--color-tint-add (a b tint)
-  "Add B scaled by TINT to color A, making it lighter."
+  "Tint color lighter from A to B by TINT amount."
   (declare (important-return-value t))
   (vector
    (+ (aref a 0) (* tint (aref b 0)))
@@ -185,7 +188,7 @@ COLOR is a 3-element vector of RGB values."
 
 
 (defun hl-block--color-tint-sub (a b tint)
-  "Subtract B scaled by TINT from color A, making it darker."
+  "Tint colors darker from A to B by TINT amount."
   (declare (important-return-value t))
   (vector
    (- (aref a 0) (* tint (aref b 0)))
@@ -194,25 +197,24 @@ COLOR is a 3-element vector of RGB values."
 
 
 (defun hl-block--overlay-create-color-tint (block-list end-fallback)
-  "Create overlays with tinted backgrounds for nested blocks.
-Argument BLOCK-LIST represents start-end ranges of brackets.
+  "Update the overlays based on the cursor location.
+Argument BLOCK-LIST represents start-end ranges of braces.
 Argument END-FALLBACK is the point used when no matching end bracket is found,
-typically the result of calling `point'."
+typically `(point)'."
   (declare (important-return-value nil))
   (let* ((block-list-len (length block-list))
          (bg-color (apply #'vector (color-values (face-attribute 'default :background))))
          (bg-color-tint (apply #'vector (color-values hl-block-color-tint)))
-         ;; Check if background is light or dark.
-         ;; 98304 = 65535 * 1.5, i.e. 50% of max RGB sum (65535 * 3).
+         ;; Check dark background is light/dark.
          (do-highlight (> 98304 (+ (aref bg-color 0) (aref bg-color 1) (aref bg-color 2))))
-         ;; Tint level counter.
+         ;; Iterator.
          (i 0))
     (pcase-let ((`(,beg-prev . ,end-prev) (pop block-list)))
-      (unless end-prev ; May be `nil' for unmatched brackets.
+      (unless end-prev ; May be `nil' for un-matched brackets.
         (setq end-prev end-fallback))
       (while block-list
         (pcase-let ((`(,beg . ,end) (pop block-list)))
-          (unless end ; May be `nil' for unmatched brackets.
+          (unless end ; May be `nil' for un-matched brackets.
             (setq end end-fallback))
           (let ((elem-overlay-beg (make-overlay beg beg-prev))
                 (elem-overlay-end (make-overlay end-prev end)))
@@ -233,28 +235,29 @@ typically the result of calling `point'."
               (overlay-put elem-overlay-beg 'face hl-face)
               (overlay-put elem-overlay-end 'face hl-face))
 
-            (push elem-overlay-beg hl-block--overlays)
-            (push elem-overlay-end hl-block--overlays)
+            (push elem-overlay-beg hl-block--overlay)
+            (push elem-overlay-end hl-block--overlay)
             (setq beg-prev beg)
             (setq end-prev end))
           (incf i))))))
 
 
 ;; ---------------------------------------------------------------------------
-;; Internal Bracket (Draw Style)
+;; Internal Color Tint (Draw Style)
 
 (defun hl-block--overlay-create-bracket (block-list)
-  "Create overlays to highlight surrounding brackets.
-Argument BLOCK-LIST represents start-end ranges of brackets."
+  "Update the overlays based on the cursor location.
+Argument BLOCK-LIST represents start-end ranges of braces."
   (declare (important-return-value nil))
+  ;; hl-block-bracket-face
   (pcase-dolist (`(,beg . ,end) block-list)
     (let ((elem-overlay-beg (make-overlay beg (1+ beg))))
       (overlay-put elem-overlay-beg 'face hl-block-bracket-face)
-      (push elem-overlay-beg hl-block--overlays)
-      (when end ; May be `nil' for unmatched brackets.
+      (push elem-overlay-beg hl-block--overlay)
+      (when end ; May be `nil' for un-matched brackets.
         (let ((elem-overlay-end (make-overlay (1- end) end)))
           (overlay-put elem-overlay-end 'face hl-block-bracket-face)
-          (push elem-overlay-end hl-block--overlays))))))
+          (push elem-overlay-end hl-block--overlay))))))
 
 
 ;; ---------------------------------------------------------------------------
@@ -263,8 +266,8 @@ Argument BLOCK-LIST represents start-end ranges of brackets."
 (defun hl-block--overlay-clear ()
   "Clear all overlays."
   (declare (important-return-value nil))
-  (mapc #'delete-overlay hl-block--overlays)
-  (setq hl-block--overlays nil))
+  (mapc 'delete-overlay hl-block--overlay)
+  (setq hl-block--overlay nil))
 
 
 (defun hl-block--overlay-refresh ()
@@ -304,28 +307,26 @@ Argument BLOCK-LIST represents start-end ranges of brackets."
 ;; This works as follows:
 ;;
 ;; - The timer is kept active as long as the local mode is enabled.
-;; - Entering a buffer runs the buffer-local `window-state-change-hook'
+;; - Entering a buffer runs the buffer local `window-state-change-hook'
 ;;   immediately which checks if the mode is enabled,
-;;   sets up the global timer if it is.
-;; - Switching any other buffer won't run this hook,
-;;   we rely on the idle timer itself running, which detects the active mode,
-;;   canceling itself if the mode isn't active.
+;;   set up the global timer if it is.
+;; - Switching any other buffer wont run this hook,
+;;   rely on the idle timer it's self running, which detects the active mode,
+;;   canceling it's self if the mode isn't active.
 ;;
 ;; This is a reliable way of using a global,
-;; repeating idle timer that is effectively buffer-local.
+;; repeating idle timer that is effectively buffer local.
 ;;
 
-(defvar hl-block--global-timer nil
-  "Global idle timer for highlighting, active while buffer-local mode is enabled.")
-
-(defvar hl-block--dirty-flush-all nil
-  "When non-nil, the timer will update all dirty buffers in visible windows.")
-
-(defvar-local hl-block--dirty nil
-  "When non-nil, the buffer should be updated when inactive.")
+;; Global idle timer (repeating), keep active while the buffer-local mode is enabled.
+(defvar hl-block--global-timer nil)
+;; When t, the timer will update buffers in all other visible windows.
+(defvar hl-block--dirty-flush-all nil)
+;; When true, the buffer should be updated when inactive.
+(defvar-local hl-block--dirty nil)
 
 (defun hl-block--time-callback-or-disable ()
-  "Timer callback that refreshes highlighting."
+  "Callback that run the repeat timer."
   (declare (important-return-value nil))
 
   ;; Ensure all other buffers are highlighted on request.
@@ -342,18 +343,17 @@ Argument BLOCK-LIST represents start-end ranges of brackets."
       (setq hl-block--dirty-flush-all t)))
 
     (when hl-block--dirty-flush-all
-      ;; Refresh overlays for all dirty buffers in visible windows.
+      ;; Run the mode callback for all other buffers in the queue.
       (dolist (frame (frame-list))
-        (when (frame-live-p frame)
-          (dolist (win (window-list frame -1))
-            (let ((buf (window-buffer win)))
-              (when (and (buffer-local-value 'hl-block-mode buf)
-                         (buffer-local-value 'hl-block--dirty buf))
-                (with-selected-frame frame
-                  (with-selected-window win
-                    (with-current-buffer buf
-                      (setq hl-block--dirty nil)
-                      (hl-block--overlay-refresh))))))))))
+        (dolist (win (window-list frame -1))
+          (let ((buf (window-buffer win)))
+            (when (and (buffer-local-value 'hl-block-mode buf)
+                       (buffer-local-value 'hl-block--dirty buf))
+              (with-selected-frame frame
+                (with-selected-window win
+                  (with-current-buffer buf
+                    (setq hl-block--dirty nil)
+                    (hl-block--overlay-refresh)))))))))
     ;; Always keep the current buffer dirty
     ;; so navigating away from this buffer will refresh it.
     (when is-mode-active
@@ -362,7 +362,7 @@ Argument BLOCK-LIST represents start-end ranges of brackets."
     (cond
      (is-mode-active
       (hl-block--overlay-refresh))
-     (t ;; Cancel the timer until the current buffer uses this mode again.
+     (t ; Cancel the timer until the current buffer uses this mode again.
       (hl-block--time-ensure nil)))))
 
 (defun hl-block--time-ensure (state)
@@ -372,16 +372,16 @@ Argument BLOCK-LIST represents start-end ranges of brackets."
    (state
     (unless hl-block--global-timer
       (setq hl-block--global-timer
-            (run-with-idle-timer hl-block-delay :repeat #'hl-block--time-callback-or-disable))))
+            (run-with-idle-timer hl-block-delay :repeat 'hl-block--time-callback-or-disable))))
    (t
     (when hl-block--global-timer
       (cancel-timer hl-block--global-timer)
       (setq hl-block--global-timer nil)))))
 
 (defun hl-block--time-reset ()
-  "Reset timer state when window state changes."
+  "Run this when the buffer was changed."
   (declare (important-return-value nil))
-  ;; Ensure changing windows doesn't leave other buffers with stale highlighting.
+  ;; Ensure changing windows doesn't leave other buffers with stale highlight.
   (cond
    ((bound-and-true-p hl-block-mode)
     (setq hl-block--dirty-flush-all t)
@@ -391,7 +391,7 @@ Argument BLOCK-LIST represents start-end ranges of brackets."
     (hl-block--time-ensure nil))))
 
 (defun hl-block--time-buffer-local-enable ()
-  "Ensure buffer-local state is enabled."
+  "Ensure buffer local state is enabled."
   (declare (important-return-value nil))
   ;; Needed in case focus changes before the idle timer runs.
   (setq hl-block--dirty-flush-all t)
@@ -400,7 +400,7 @@ Argument BLOCK-LIST represents start-end ranges of brackets."
   (add-hook 'window-state-change-hook #'hl-block--time-reset nil t))
 
 (defun hl-block--time-buffer-local-disable ()
-  "Ensure buffer-local state is disabled."
+  "Ensure buffer local state is disabled."
   (declare (important-return-value nil))
   (kill-local-variable 'hl-block--dirty)
   (hl-block--time-ensure nil)
@@ -414,14 +414,14 @@ Argument BLOCK-LIST represents start-end ranges of brackets."
   (declare (important-return-value nil))
   (hl-block--time-buffer-local-enable)
 
-  ;; Set up brackets:
+  ;; Setup brackets:
   ;; Keep as nil to match all brackets,
-  ;; otherwise convert the string to a list of characters.
+  ;; use a string to convert the string to a list.
   (let ((bracket-orig (append hl-block-bracket nil)))
     ;; Make a local, sanitized version of this variable.
     (setq-local hl-block-bracket nil)
     (when bracket-orig
-      ;; Filter for characters with open-bracket syntax.
+      ;; Filter for recognized values.
       (while bracket-orig
         (let ((ch (pop bracket-orig)))
           (when (eq ?\( (char-syntax ch))
@@ -431,14 +431,14 @@ Argument BLOCK-LIST represents start-end ranges of brackets."
   "Turn off `hl-block-mode' for the current buffer."
   (declare (important-return-value nil))
   (hl-block--overlay-clear)
-  (kill-local-variable 'hl-block--overlays)
+  (kill-local-variable 'hl-block--overlay)
   (kill-local-variable 'hl-block-bracket)
   (hl-block--time-buffer-local-disable))
 
 (defun hl-block--mode-turn-on ()
-  "Enable `hl-block-mode' in the current buffer."
+  "Enable command `hl-block-mode'."
   (declare (important-return-value nil))
-  (when (and (null (minibufferp)) (not (bound-and-true-p hl-block-mode)))
+  (when (and (not (minibufferp)) (not (bound-and-true-p hl-block-mode)))
     (hl-block-mode 1)))
 
 ;; ---------------------------------------------------------------------------
@@ -446,7 +446,7 @@ Argument BLOCK-LIST represents start-end ranges of brackets."
 
 ;;;###autoload
 (define-minor-mode hl-block-mode
-  "Highlight blocks surrounding the cursor."
+  "Highlight block under the cursor."
   :global nil
   :lighter hl-block-mode-lighter
 
